==> element-ui-1.3.1.jar: META-INF/resources/webjars/element-ui/1.3.1/lib/umd/locale/sk.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/sk', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.sk = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Zmazať'
      },
      datepicker: {
        now: 'Teraz',
        today: 'Dnes',
        cancel: 'Zrušiť',
        clear: 'Zmazať',
        confirm: 'OK',
        selectDate: 'Vybrať dátum',
        selectTime: 'Vybrať čas',
        startDate: 'Dátum začiatku',
        startTime: 'Čas začiatku',
        endDate: 'Dátum konca',
        endTime: 'Čas konca',
        day: 'Deň',
        week: 'Týždeň',
        month: 'Mesiac',
        year: 'Rok',
        month1: 'Január',
        month2: 'Február',
        month3: 'Marec',
        month4: 'Apríl',
        month5: 'Máj',
        month6: 'Jún',
        month7: 'Júl',
        month8: 'August',
        month9: 'September',
        month10: 'Október',
        month11: 'November',
        month12: 'December',
        weeks: {
          sun: 'Ne',
          mon: 'Po',
          tue: 'Ut',
          wed: 'St',
          thu: 'Št',
          fri: 'Pi',
          sat: 'So'
        },
        months: {
          jan: 'Jan',
          feb: 'Feb',
          mar: 'Mar',
          apr: 'Apr',
          may: 'Máj',
          jun: 'Jún',
          jul: 'Júl',
          aug: 'Aug',
          sep: 'Sep',
          oct: 'Okt',
          nov: 'Nov',
          dec: 'Dec'
        }
      },
      select: {
        loading: 'Načítavanie',
        noMatch: 'Žiadna zhoda',
        noData: 'Žiadne dáta',
        placeholder: 'Vybrať'
      },
      cascader: {
        noMatch: 'Žiadna zhoda',
        placeholder: 'Vybrať'
      },
      pagination: {
        goto: 'Choď na',
        pagesize: 'na stranu',
        total: 'Všetko {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Správa',
        confirm: 'OK',
        cancel: 'Zrušiť',
        error: 'Neplatný vstup'
      },
      upload: {
        delete: 'Vymazať',
        preview: 'Prehliadať',
        continue: 'Pokračovať'
      },
      table: {
        emptyText: 'Žiadne dáta',
        confirmFilter: 'Potvrdiť',
        resetFilter: 'Zresetovať',
        clearFilter: 'Všetko',
        sumText: 'Sum' // to be translated
      },
      tree: {
        emptyText: 'Žiadne dáta'
      },
      transfer: {
        noMatch: 'Žiadna zhoda',
        noData: 'Žiadne dáta',
        titles: ['List 1', 'List 2'], // to be translated
        filterPlaceholder: 'Enter keyword', // to be translated
        noCheckedFormat: '{total} items', // to be translated
        hasCheckedFormat: '{checked}/{total} checked' // to be translated
      }
    }
  };
  module.exports = exports['default'];
});

==> element-ui-1.4.11.jar: META-INF/resources/webjars/element-ui/1.4.11/lib/umd/locale/sk.js <==
(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define('element/locale/sk', ['module', 'exports'], factory);
  } else if (typeof exports !== "undefined") {
    factory(module, exports);
  } else {
    var mod = {
      exports: {}
    };
    factory(mod, mod.exports);
    global.ELEMENT.lang = global.ELEMENT.lang || {}; 
    global.ELEMENT.lang.sk = mod.exports;
  }
})(this, function (module, exports) {
  'use strict';

  exports.__esModule = true;
  exports.default = {
    el: {
      colorpicker: {
        confirm: 'OK',
        clear: 'Zmazať'
      },
      datepicker: {
        now: 'Teraz',
        today: 'Dnes',
        cancel: 'Zrušiť',
        clear: 'Zmazať',
        confirm: 'OK',
        selectDate: 'Vybrať dátum',
        selectTime: 'Vybrať čas',
        startDate: 'Dátum začiatku',
        startTime: 'Čas začiatku',
        endDate: 'Dátum konca',
        endTime: 'Čas konca',
        day: 'Deň',
        week: 'Týždeň',
        month: 'Mesiac',
        year: 'Rok',
        month1: 'Január',
        month2: 'Február',
        month3: 'Marec',
        month4: 'Apríl',
        month5: 'Máj',
        month6: 'Jún',
        month7: 'Júl',
        month8: 'August',
        month9: 'September',
        month10: 'Október',
        month11: 'November',
        month12: 'December',
        weeks: {
          sun: 'Ne',
          mon: 'Po',
          tue: 'Ut',
          wed: 'St',
          thu: 'Št',
          fri: 'Pi',
          sat: 'So'
        },
        months: {
          jan: 'Jan',
          feb: 'Feb',
          mar: 'Mar',
          apr: 'Apr',
          may: 'Máj',
          jun: 'Jún',
          jul: 'Júl',
          aug: 'Aug',
          sep: 'Sep',
          oct: 'Okt',
          nov: 'Nov',
          dec: 'Dec'
        }
      },
      select: {
        loading: 'Načítavanie',
        noMatch: 'Žiadna zhoda',
        noData: 'Žiadne dáta',
        placeholder: 'Vybrať'
      },
      cascader: {
        noMatch: 'Žiadna zhoda',
        loading: 'Načítavanie',
        placeholder: 'Vybrať'
      },
      pagination: {
        goto: 'Choď na',
        pagesize: 'na stranu',
        total: 'Všetko {total}',
        pageClassifier: ''
      },
      messagebox: {
        title: 'Správa',
        confirm: 'OK',
        cancel: 'Zrušiť',
        error: 'Neplatný vstup'
      },
      upload: {
        delete: 'Vymazať',
        preview: 'Prehliadať',
        continue: 'Pokračovať'
      },
      table: {
        emptyText: 'Žiadne dáta',
        confirmFilter: 'Potvrdiť',
        resetFilter: 'Zresetovať',
        clearFilter: 'Všetko',
        sumText: 'Spolu'
      },
      tree: {
        emptyText: 'Žiadne dáta'
      },
      transfer: {
        noMatch: 'Žiadna zhoda',
        noData: 'Žiadne dáta',
        titles: ['Zoznam 1', 'Zoznam 2'],
        filterPlaceholder: 'Filtrovať podľa',
        noCheckedFormat: '{total} položiek',
        hasCheckedFormat: '{checked}/{total} označených'
      }
    }
  };
  module.exports = exports['default'];
});
